@@ -5,9 +5,15 @@ import click
 from . import launchable
 from ..utils.file_name_pattern import jvm_test_pattern
 
+@click.option('--bare',
+    help='outputs class names alone',
+    default=False,
+    is_flag=True
+)
+
 @click.argument('source_roots', required=True, nargs=-1)
 @launchable.subset
-def subset(client, source_roots):
+def subset(client, bare, source_roots):
     def file2test(f: str):
         if jvm_test_pattern.match(f):
             f = f[:f.rindex('.')]   # remove extension
@@ -20,8 +26,11 @@ def subset(client, source_roots):
     for root in source_roots:
         client.scan(root, '**/*', file2test)
 
-    client.formatter = lambda x: "--tests {}".format(x[0]['name'])
-    client.separator = ' '
+    if bare:
+        client.formatter = lambda x: x[0]['name']
+    else:
+        client.formatter = lambda x: "--tests {}".format(x[0]['name'])
+        client.separator = ' '
 
     client.run()
 
